@@ -34,15 +34,15 @@ public:
     explicit EntityAnnotationsAttribute(const QMap<QByteArray, QByteArray> &annotations);
 
     void setAnnotations(const QMap<QByteArray, QByteArray> &annotations);
-    QMap<QByteArray, QByteArray> annotations() const;
+    Q_REQUIRED_RESULT QMap<QByteArray, QByteArray> annotations() const;
 
     void insert(const QByteArray &key, const QString &value);
-    QString value(const QByteArray &key) const;
-    bool contains(const QByteArray &key) const;
+    Q_REQUIRED_RESULT QString value(const QByteArray &key) const;
+    Q_REQUIRED_RESULT bool contains(const QByteArray &key) const;
 
-    QByteArray type() const override;
+    Q_REQUIRED_RESULT QByteArray type() const override;
     Attribute *clone() const override;
-    QByteArray serialized() const override;
+    Q_REQUIRED_RESULT QByteArray serialized() const override;
     void deserialize(const QByteArray &data) override;
 
 private:
