@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONFETCHJOB_H
-#define AKONADI_COLLECTIONFETCHJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "collection.h"
@@ -177,5 +176,3 @@ private:
 };
 
 }
-
-#endif
