@@ -13,7 +13,8 @@
 class QObject;
 class QString;
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-template<typename T> class QVector;
+template<typename T>
+class QVector;
 #else
 template<typename T>
 class QList;
@@ -84,4 +85,3 @@ AKONADICORE_EXPORT void overridePluginLookup(QObject *plugin);
 }
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Akonadi::TypePluginLoader::Options)
-
