@@ -21,7 +21,7 @@
 #include <QStandardPaths>
 
 #include <config-akonadi.h>
-#ifdef HAVE_UNISTD_H
+#if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <chrono>
