@@ -59,7 +59,8 @@ Query::Condition conditionFromFqNames(const QStringList &fqNames);
 /**
  * Convenience overload for the above.
  */
-template<template<typename> class T> Query::Condition conditionFromFqNames(const T<QByteArray> &fqNames)
+template<template<typename> class T>
+Query::Condition conditionFromFqNames(const T<QByteArray> &fqNames)
 {
     Query::Condition c;
     c.setSubQueryMode(Query::Or);
@@ -86,4 +87,3 @@ QString fullName(const PartType &type);
 
 } // namespace Server
 } // namespace Akonadi
-
